@@ -4,11 +4,11 @@
 import configparser
 from typing import List, Optional, Tuple
 
-from UM.PluginRegistry import PluginRegistry
 from UM.Logger import Logger
 from UM.Settings.ContainerFormatError import ContainerFormatError
 from UM.Settings.InstanceContainer import InstanceContainer  # The new profile to make.
 from cura.CuraApplication import CuraApplication
+from cura.Machines.QualityManager import getMachineDefinitionIDForQualitySearch
 from cura.ReaderWriters.ProfileReader import ProfileReader
 
 import zipfile
@@ -92,6 +92,14 @@ class CuraProfileReader(ProfileReader):
         except Exception as e:
             Logger.log("e", "Error while trying to parse profile: %s", str(e))
             return None
+
+        global_stack = CuraApplication.getInstance().getGlobalContainerStack()
+        if global_stack is None:
+            return None
+
+        active_quality_definition = getMachineDefinitionIDForQualitySearch(global_stack.definition)
+        if profile.getMetaDataEntry("definition") != active_quality_definition:
+            profile.setMetaDataEntry("definition", active_quality_definition)
         return profile
 
     ##  Upgrade a serialized profile to the current profile format.
