@@ -64,7 +64,8 @@ class BuildVolume(SceneNode):
 
         self._origin_mesh = None  # type: Optional[MeshData]
         self._origin_line_length = 20
-        self._origin_line_width = 0.5
+        self._origin_line_width = 1.5
+        self._enabled = False
 
         self._grid_mesh = None   # type: Optional[MeshData]
         self._grid_shader = None
@@ -258,7 +259,7 @@ class BuildVolume(SceneNode):
                     node.setOutsideBuildArea(True)
                     continue
 
-                if node.collidesWithArea(self.getDisallowedAreas()):
+                if node.collidesWithAreas(self.getDisallowedAreas()):
                     node.setOutsideBuildArea(True)
                     continue
                 # If the entire node is below the build plate, still mark it as outside.
@@ -312,7 +313,7 @@ class BuildVolume(SceneNode):
                 node.setOutsideBuildArea(True)
                 return
 
-            if node.collidesWithArea(self.getDisallowedAreas()):
+            if node.collidesWithAreas(self.getDisallowedAreas()):
                 node.setOutsideBuildArea(True)
                 return
 
@@ -770,7 +771,7 @@ class BuildVolume(SceneNode):
 
         self._has_errors = len(self._error_areas) > 0
 
-        self._disallowed_areas = []  # type: List[Polygon]
+        self._disallowed_areas = []
         for extruder_id in result_areas:
             self._disallowed_areas.extend(result_areas[extruder_id])
         self._disallowed_areas_no_brim = []
